quantizationtools.QuantizationJob
=================================

.. abjad-lineage:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob

.. autoclass:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.job_id
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.q_event_proxies
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.q_grids
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QuantizationJob.QuantizationJob.QuantizationJob.__setstate__
   :noindex:
